//*************************************************
// CONTROLLO REMOTO RELE' E TEMPERATURA
// http://www.settorezero.com
//
// modulo: main.c
// autore: Bernardo Giovanni
// data:  01/06/10
// picmicro: PIC16F88
// clock: 4MHz
//
//*************************************************
/*
Configurazione:
Protezioni eeprom/memoria programma disattivate
Modulo CCP su pin RB3
Debug disattivato
Programmazione a basso voltaggio disattivata
Brown Out Reset disattivato
MLCR con normale funzione di Master Clear Reset
PowerUp timer disattivato
Clock esterno ad alta velocit
*/

#define  XTAL_FREQ 4MHZ // richiesto da delay.c
#include <pic.h>

__CONFIG(UNPROTECT & CCPRB3 & DEBUGDIS & LVPDIS & BORDIS & MCLREN & PWRTDIS & WDTDIS & HS);
__CONFIG(0); // seconda word di configurazione

#include "settings.h"
#include "usart.c"
#include "delay.c"

void main(void)
	{
	settings(); // imposto le porte come da settings.h	
	init_comms(); // set up the USART - settings defined in usart.h
	DelayMs(50); // ritardo iniziale per consentire la stabilizzazione
	
	// Rel spenti all'avvio
	REL1=1;
	REL2=1;
		
	GIE=1; // gestione globale interrupt attiva
	TMR0IE=1; // interrupt su timer0 attivo
	PEIE=1; // interrupt di periferica attivi
	RCIE=1; // interrupt di ricezione su seriale attivo
	ADIE=1; // interrupt di fine conversione analogico/digitale attivo
		
	// stringhe iniziali di test
	printf("Controllo remoto rele e temperatura\n\r");
	printf("(C)2010 Bernardo Giovannni\n\r");
	printf("www.settorezero.com\n\r\n\r");
	
	while(1)
		{
		//  stata segnalata la lettura dello stato dei rel
		if (readstat)
			{
			printf("RELAY 1: ");
			if (REL1==1)
				{printf(" OFF");}
			else
				{printf(" ON");}
			printf("\n\rRELAY 2: ");
			if (REL2==1)
				{printf(" OFF");}
			else
				{printf(" ON");}
			printf("\n\r");
			readstat=0; // azzero il flag
			} // \readstat
	
		//  stata segnalata la lettura della temperatura
		if (readtemp)
			{
			printf("Temperature: %d.%d \n\r",((temperatura*5)/10),((temperatura*5)%10)); 
			readtemp=0; // azzero il flag
			}// \readtemp
		}// \while(1)
	}// \main
	
void interrupt isr(void)
	{
	// INTERRUPT CAUSATO DA RICEZIONE BYTE SU USART
	if (RCIF)
		{
		input = getch(); // memorizzo il carattere (il byte) ricevuto

		// se  stata premuta la R o la r in precedenza
		if (relmode)
			{
			switch(input)
				{
				case '1': // invertire rel1
				REL1^=1;
				printf("1 : ok\n\r");
				printf("RELAY 1 now is ");
				if (REL1)
					{
					printf("OFF");
					}
				else
					{
					printf("ON");
					}
				printf("\n\r");
				break;

				case '2': // invertire rel2
				REL2^=1;
				printf("2 : ok\n\r");
				printf("RELAY 2 now is ");
				if (REL2)
					{
					printf("OFF");
					}
				else
					{
					printf("ON");
					}
				printf("\n\r");
				break;
				
				default: // altro caso
				putch(input);
				printf(" : invalid entry\n\r");
				break;
				}
			relmode=0;
			}
		else
			{
			switch(input)
				{
				case 'R':
				case 'r':
				relmode=1; // modalit gestione rel on/off
				printf("R");
				break;
				
				case 'T':
				case 't':
				readtemp=1; // segnalo nel main di scrivere il valore di temperatura
				break;
				
				case 'S':
				case 's':
				readstat=1; // segnalo nel main di inviare la lettura dello stato dei rel
				break;
				}
			}
		} // \RCIF

	
	// INTERRUPT CAUSATO DA FINE CONVERSIONE ANALOGICO/DIGITALE
	if (ADIF)
		{
		tempt=ADRESL + (ADRESH<<8); // valore attuale di temperatura
		tempm+=tempt; // sommo il valore
		tempvalues--; // decremento il numero di valori letti
		if (tempvalues==0) // sono arrivato a zero => ho fatto dieci letture
			{
			temperatura=(tempm/10); // valore di temperatura medio su 10 valori
			tempm=0; // azzero la media
			tempvalues=10; // ricarico il contatore dei valori sommati
			}
		ADIF=0; // resetto il flag di fine conversione A/D
		}
		
	// INTERRUPT CAUSATO DA OVERFLOW TIMER0
	if (TMR0IF)
		{
		TMR0=8; // ricarico il timer0
		counttemp--; // counter avvio lettura sonda
		if (counttemp==0) // il counter  arrivato a zero?
			{
			ADGO=1; // avvio la conversione
			counttemp=100; // ricarico il contatore, la conversione verr avviata ogni 100mS
			}
		TMR0IF=0; // azzero flag interrupt
		}
	} // \ISR