//*************************************************
//
// settings.h
// autore: Bernardo Giovanni (www.settorezero.com)
// data: 01/06/10
//
//*************************************************

#define REL1	RA2 // Rel 1 su RA2
#define REL2	RA1 // Rel 2 su RA1
unsigned char input=0; // buffer di ricezione seriale
unsigned int temperatura=0; // valore di temperatura da mostrare
unsigned int tempt=0; // valore di temperatura appena letto
unsigned int tempm=0; // valore medio temperatura
unsigned char tempvalues=10; // n valori di temperatura da sommare per fare la media
unsigned char counttemp=100; // lettura della sonda ogni 100ms
bit relmode; // flag per capire se devo gestire i rel o meno
bit readtemp; // flag per attivare la lettura della temperatura
bit readstat; // flag per attivare la lettura dello stato dei rel
bit calctemp; // flag per abilitare la lettura dei registri ADRES

// prototipi di funzione
void settings(void);
void main(void);
void interrupt isr(void);

void settings(void)
	{
	// Collegamenti:
	// RB2 = USART RX (ingresso)
	// RB5 = USART TX (ingresso)
	// RB7/AN6 = sonda di temperatura LM35 (ingresso)
	// RA1 = rel 2 (uscita)
	// RA2 = rel 1 (uscita)
	TRISA=0b00000000; 
	// RB2 e RB5 => USART, impostare come ingressi
	// in realt non ce ne sarebbe bisogno in quanto verranno comunque impostati come ingressi dalle macro contenute in "usart.c"
	TRISB=0b10100100; // anche RB7 da impostare come ingresso per avere funzione analogica
		
	CMCON=7; // Comparatori disattivati
	
	// Il 16F88 permette di scegliere singolarmente le porte da utilizzare come analogiche ponendo a 1
	// il relativo bit nel registro denominato "ANSEL"
	ANSEL=0b01000000; // Abilito solo AN6 con funzione analogica. AN6 si trova su RB7
	
	ADCON0=0b01110001;
	// bit 0 -> ADON		Abilitazione modulo ADC, 1=Acceso , 0=Spento
	// bit 1 -> NON USATO
	// bit 2 -> GO/DONE		Stato di conversione 1=avvia conversione , 0=conversione finita
	// bit 3 -> CHS0		Selezione della porta analogica da leggere
	// bit 4 -> CHS1		Selezione della porta analogica da leggere
	// bit 5 -> CHS2		Selezione della porta analogica da leggere
	// 						abbiamo preselezionato la porta AN6 (110) 
	//						in quanto  qui che abbiamo collegato la sonda LM35
	// bit 6 -> ADCS0		Frequenza di conversione A/D    
	// bit 7 -> ADCS1       Frequenza di conversione A/D
	// 						abbiamo scelto Fosc/8 in quanto, con l'oscillatore a 4MHz
	//						ci garantisce un TAD di 2uS (deve essere minimo 1,6uS)
	
	ADCON1=0b10000000;
	// bit 0:3 -> non usati su pic16F88
	// bit 4:5 -> riferimento di tensione: Vdd-Vss
	// bit 6 -> ADCS2	unito a ADCS1 e a ADCS0 su ADCON0 per impostare la frequenza di campionamento
	// bit 7 -> ADFM	1: giustificazione a destra, 0: giustificazione a sinistra

	// imposto il prescaler a 1:4 e precarico il timer0 a 8 (6+2) in maniera
	// da avere un interrupt ogni millisecondo col quarzo da 4MHz
	OPTION=0b11000001;
	// bit 0 -> Prescaler Rate Select bit 0
	// bit 1 -> Prescaler Rate Select bit 0
	// bit 2 -> Prescaler Rate Select bit 0 (1:4)
	// bit 3 -> Prescaler assegnato al Timer0 
	// bit 4 -> Non importa
	// bit 5 -> Clock per Timer0 derivato da ciclo di clock interno
	// bit 6 -> Non importa
	// bit 7 -> Resistenze di pull-up su porta B disattivate
	TMR0=8; // preload timer0
	}